Soundify class

Core class for managing audio and sensory feedback.

Constructors

Soundify({required List<SoundRule> rules})
Constructs a Soundify instance with a list of SoundRules.

Properties

hashCode int
The hash code for this object.
no setterinherited
rules List<SoundRule>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Cleans up resources and subscriptions.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
trigger(BuildContext? context, {dynamic data}) → void
Triggers audio and haptic feedback based on the provided data and optional context.

Operators

operator ==(Object other) bool
The equality operator.
inherited