Soundify class
Core class for managing audio and sensory feedback.
Constructors
Properties
Methods
-
dispose(
) → void - Cleans up resources and subscriptions.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
trigger(
BuildContext? context, {dynamic data}) → void -
Triggers audio and haptic feedback based on the provided
dataand optionalcontext.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited